@@ -30,88 +30,83 @@ from __future__ import annotations
 from typing import Any
 from typing import Callable
 from typing import Optional
-from typing import Union
 from typing import TYPE_CHECKING
+from typing import Union
 
-import sys
-import re
-import os
-import subprocess
-import hashlib
-import shlex
-import socket
-import logging
-import json
-import copy
 import collections
-import platform
+import copy
 import functools
-from collections import defaultdict
-import random
-import weakref
+import hashlib
 import inspect
+import json
+import logging
+import os
+import platform
+import random
+import re
+import socket
 import string
+import sys
+import unicodedata
+import weakref
 import webbrowser
-from string import Template
+from collections import defaultdict
 from datetime import datetime
 from datetime import timedelta
-from urllib.parse import unquote
-from urllib.parse import urlparse
 from functools import wraps
 from pathlib import Path
-from packaging.version import Version as V
-import unicodedata
+from string import Template
+from urllib.parse import unquote
+from urllib.parse import urlparse
 
+import precis_i18n.codec  # noqa: F401
 from cryptography import x509
 from cryptography.hazmat.backends import default_backend
-
-from nbxmpp.namespaces import Namespace
-from nbxmpp.const import Role
-from nbxmpp.const import Chatstate
-from nbxmpp.const import ConnectionProtocol
-from nbxmpp.const import ConnectionType
-from nbxmpp.const import Affiliation
-from nbxmpp.errors import StanzaError
-from nbxmpp.structs import CommonError
-from nbxmpp.structs import ProxyData
-from nbxmpp.protocol import JID
-from nbxmpp.protocol import InvalidJid
-from nbxmpp.protocol import Iq
-
 from gi.repository import Gio
 from gi.repository import GLib
 from gi.repository import GObject
-from gi.repository import Soup
-
-import precis_i18n.codec  # noqa: F401
+from nbxmpp.const import Affiliation
+from nbxmpp.const import Chatstate
+from nbxmpp.const import ConnectionProtocol
+from nbxmpp.const import ConnectionType
+from nbxmpp.const import Role
+from nbxmpp.errors import StanzaError
+from nbxmpp.namespaces import Namespace
+from nbxmpp.protocol import InvalidJid
+from nbxmpp.protocol import Iq
+from nbxmpp.protocol import JID
+from nbxmpp.structs import CommonError
+from nbxmpp.structs import ProxyData
+from packaging.version import Version as V
 
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common import iana
-from gajim.common.i18n import Q_
-from gajim.common.i18n import _
-from gajim.common.i18n import ngettext
-from gajim.common.i18n import get_rfc5646_lang
+from gajim.common import types
+from gajim.common.const import CONSONANTS
+from gajim.common.const import GIO_TLS_ERRORS
+from gajim.common.const import SHOW_LIST
 from gajim.common.const import SHOW_STRING
 from gajim.common.const import SHOW_STRING_MNEMONIC
 from gajim.common.const import URIType
-from gajim.common.const import XmppUriQuery
-from gajim.common.const import GIO_TLS_ERRORS
-from gajim.common.const import SHOW_LIST
-from gajim.common.const import CONSONANTS
 from gajim.common.const import VOWELS
-from gajim.common.regex import INVALID_XML_CHARS_REGEX
+from gajim.common.const import XmppUriQuery
+from gajim.common.dbus.file_manager import DBusFileManager
+from gajim.common.i18n import _
+from gajim.common.i18n import get_rfc5646_lang
+from gajim.common.i18n import ngettext
+from gajim.common.i18n import p_
 from gajim.common.structs import URI
-from gajim.common import types
+
 if TYPE_CHECKING:
     from gajim.common.modules.util import LogAdapter
 
 HAS_PYWIN32 = False
 if os.name == 'nt':
     try:
-        import win32file
-        import win32con
         import pywintypes
+        import win32con
+        import win32file
         HAS_PYWIN32 = True
     except ImportError:
         pass
@@ -183,28 +178,28 @@ def get_uf_show(show: str, use_mnemonic: bool = False) -> str:
 
 def get_uf_sub(sub: str) -> str:
     if sub == 'none':
-        uf_sub = Q_('?Subscription we already have:None')
-    elif sub == 'to':
-        uf_sub = _('To')
-    elif sub == 'from':
-        uf_sub = _('From')
-    elif sub == 'both':
-        uf_sub = _('Both')
-    else:
-        uf_sub = _('Unknown')
+        return p_('Contact subscription', 'None')
 
-    return uf_sub
+    if sub == 'to':
+        return p_('Contact subscription', 'To')
+
+    if sub == 'from':
+        return p_('Contact subscription', 'From')
+
+    if sub == 'both':
+        return p_('Contact subscription', 'Both')
+
+    return p_('Contact subscription', 'Unknown')
 
 
 def get_uf_ask(ask: Union[str, None]) -> str:
     if ask is None:
-        uf_ask = Q_('?Ask (for Subscription):None')
-    elif ask == 'subscribe':
-        uf_ask = _('Subscribe')
-    else:
-        uf_ask = ask
+        return p_('Contact subscription', 'None')
 
-    return uf_ask
+    if ask == 'subscribe':
+        return p_('Contact subscription', 'Subscribe')
+
+    return ask
 
 
 def get_uf_role(role: Union[Role, str], plural: bool = False) -> str:
@@ -213,19 +208,19 @@ def get_uf_role(role: Union[Role, str], plural: bool = False) -> str:
         role = role.value
 
     if role == 'none':
-        return Q_('?Group Chat Contact Role:None')
+        return p_('Group chat contact role', 'None')
     if role == 'moderator':
         if plural:
-            return _('Moderators')
-        return _('Moderator')
+            return p_('Group chat contact role', 'Moderators')
+        return p_('Group chat contact role', 'Moderator')
     if role == 'participant':
         if plural:
-            return _('Participants')
-        return _('Participant')
+            return p_('Group chat contact role', 'Participants')
+        return p_('Group chat contact role', 'Participant')
     if role == 'visitor':
         if plural:
-            return _('Visitors')
-        return _('Visitor')
+            return p_('Group chat contact role', 'Visitors')
+        return p_('Group chat contact role', 'Visitor')
     return ''
 
 
@@ -237,19 +232,19 @@ def get_uf_affiliation(affiliation: Union[Affiliation, str],
         affiliation = affiliation.value
 
     if affiliation == 'none':
-        return Q_('?Group Chat Contact Affiliation:None')
+        return p_('Group chat contact affiliation', 'None')
     if affiliation == 'owner':
         if plural:
-            return _('Owners')
-        return _('Owner')
+            return p_('Group chat contact affiliation', 'Owners')
+        return p_('Group chat contact affiliation', 'Owner')
     if affiliation == 'admin':
         if plural:
-            return _('Administrators')
-        return _('Administrator')
+            return p_('Group chat contact affiliation', 'Administrators')
+        return p_('Group chat contact affiliation', 'Administrator')
     if affiliation == 'member':
         if plural:
-            return _('Members')
-        return _('Member')
+            return p_('Group chat contact affiliation', 'Members')
+        return p_('Group chat contact affiliation', 'Member')
     return ''
 
 
@@ -280,13 +275,7 @@ def get_uf_relative_time(timestamp: float) -> str:
 
 def to_one_line(msg: str) -> str:
     msg = msg.replace('\\', '\\\\')
-    msg = msg.replace('\n', '\\n')
-    # s1 = 'test\ntest\\ntest'
-    # s11 = s1.replace('\\', '\\\\')
-    # s12 = s11.replace('\n', '\\n')
-    # s12
-    # 'test\\ntest\\\\ntest'
-    return msg
+    return msg.replace('\n', '\\n')
 
 
 def from_one_line(msg: str) -> str:
@@ -296,13 +285,7 @@ def from_one_line(msg: str) -> str:
     # So here match '\\n' but not if you have a '\' before that
     expr = re.compile(r'(?<!\\)\\n')
     msg = expr.sub('\n', msg)
-    msg = msg.replace('\\\\', '\\')
-    # s12 = 'test\\ntest\\\\ntest'
-    # s13 = re.sub('\n', s12)
-    # s14 s13.replace('\\\\', '\\')
-    # s14
-    # 'test\ntest\\ntest'
-    return msg
+    return msg.replace('\\\\', '\\')
 
 
 def chatstate_to_string(chatstate: Optional[Chatstate]) -> str:
@@ -324,31 +307,6 @@ def chatstate_to_string(chatstate: Optional[Chatstate]) -> str:
     raise ValueError('unknown value: %s' % chatstate)
 
 
-def exec_command(command: str,
-                 use_shell: bool = False,
-                 posix: bool = True
-                 ) -> None:
-    '''
-    execute a command. if use_shell is True, we run the command as is it was
-    typed in a console. So it may be dangerous if you are not sure about what
-    is executed.
-    '''
-    if use_shell:
-        subprocess.Popen(f'{command} &', shell=True).wait()
-    else:
-        args = shlex.split(command, posix=posix)
-        process = subprocess.Popen(args)
-        app.thread_interface(process.wait)
-
-
-def build_command(executable: str, parameter: str) -> str:
-    # we add to the parameter (can hold path with spaces)
-    # "" so we have good parsing from shell
-    parameter = parameter.replace('"', '\\"')  # but first escape "
-    command = f'{executable} "{parameter}"'
-    return command
-
-
 def sanitize_filename(filename: str) -> str:
     '''
     Sanitize filename of elements not allowed on Windows
@@ -364,7 +322,7 @@ def sanitize_filename(filename: str) -> str:
         ]
         filename = ''.join(char for char in filename if char not in blacklist)
 
-        filename = ''.join(char for char in filename if 31 < ord(char))
+        filename = ''.join(char for char in filename if ord(char) > 31)
 
         filename = unicodedata.normalize('NFKD', filename)
         filename = filename.rstrip('. ')
@@ -565,13 +523,7 @@ def get_auth_sha(sid: str, initiator: str, target: str) -> str:
     Return sha of sid + initiator + target used for proxy auth
     '''
     return hashlib.sha1(
-        (f'{sid}{initiator}{target}').encode('utf-8')).hexdigest()
-
-
-def remove_invalid_xml_chars(string_: str) -> str:
-    if string_:
-        string_ = re.sub(INVALID_XML_CHARS_REGEX, '', string_)
-    return string_
+        (f'{sid}{initiator}{target}').encode()).hexdigest()
 
 
 def get_random_string(count: int = 16) -> str:
@@ -681,9 +633,8 @@ def jid_is_blocked(account: str, jid: str) -> bool:
 
 
 def get_subscription_request_msg(account: Optional[str] = None) -> str:
-    message = _('I would like to add you to my contact list.')
     if account is None:
-        return message
+        return _('I would like to add you to my contact list.')
 
     message = app.settings.get_account_setting(
         account, 'subscription_request_msg')
@@ -795,10 +746,9 @@ class AdditionalDataDict(collections.UserDict):
 
     @staticmethod
     def _get_path_childs(full_path: str) -> list[str]:
-        path_childs = [full_path]
         if ':' in full_path:
-            path_childs = full_path.split(':')
-        return path_childs
+            return full_path.split(':')
+        return [full_path]
 
     def set_value(self, full_path: str, key: str, value: Optional[str]) -> None:
         path_childs = self._get_path_childs(full_path)
@@ -845,17 +795,6 @@ class AdditionalDataDict(collections.UserDict):
         return copy.deepcopy(self)
 
 
-class Singleton(type):
-
-    _instances: dict[Any, Any] = {}
-
-    def __call__(cls, *args: Any, **kwargs: Any):
-        if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(
-                *args, **kwargs)
-        return cls._instances[cls]
-
-
 def delay_execution(milliseconds):
     # Delay the first call for `milliseconds`
     # ignore all other calls while the delay is active
@@ -957,7 +896,7 @@ def parse_uri(uri: str) -> URI:
         if not urlparts.netloc:
             err = f'No host or empty host in an {scheme} URI'
             return URI(URIType.INVALID, uri, data={'error': err})
-        return URI(URIType.WEB, uri, data=uri)
+        return URI(URIType.WEB, uri)
 
     if scheme == 'xmpp':
         if not urlparts.path.startswith('/'):
@@ -980,17 +919,19 @@ def parse_uri(uri: str) -> URI:
                    data=data)
 
     if scheme == 'mailto':
+        data: dict[str, str] = {}
         try:
-            data = unquote(urlparts.path, errors='strict')
-            validate_jid(data, 'bare')  # meh, good enuf
+            data['addr'] = unquote(urlparts.path, errors='strict')
+            validate_jid(data['addr'], 'bare')  # meh, good enough
         except ValueError as err:
-            data = {'error': str(err)}
+            data['error'] = str(err)
             return URI(URIType.INVALID, uri, data=data)
         return URI(URIType.MAIL, uri, data=data)
 
     if scheme == 'tel':
-        data = uri[4:]
-        return URI(URIType.TEL, uri, data=data)
+        # https://rfc-editor.org/rfc/rfc3966#section-3
+        # TODO: extract number
+        return URI(URIType.TEL, uri)
 
     if scheme == 'geo':
         # TODO: unify with .preview_helpers.split_geo_uri
@@ -999,19 +940,15 @@ def parse_uri(uri: str) -> URI:
         if not lat or not lon_alt:
             return URI(URIType.INVALID, uri, data={
                        'error': 'No latitude or longitude'})
-        lon, _, _alt = lon_alt.partition(',')
+        lon, _, alt = lon_alt.partition(',')
         if not lon:
             return URI(URIType.INVALID, uri, data={'error': 'No longitude'})
 
-        # TODO: move redirection to open_uri, parsing needs to be unit-testable
-        if Gio.AppInfo.get_default_for_uri_scheme('geo'):
-            return URI(URIType.GEO, uri, data=uri)
-
-        data = geo_provider_from_location(lat, lon)
+        data = {'lat': lat, 'lon': lon, 'alt': alt}
         return URI(URIType.GEO, uri, data=data)
 
     if scheme == 'file':
-        # https://rfc-editor.org/rfc/rfc8089.html
+        # https://rfc-editor.org/rfc/rfc8089.html#section-2
         data: dict[str, str] = {}
         try:
             data['netloc'] = urlparts.netloc
@@ -1022,7 +959,35 @@ def parse_uri(uri: str) -> URI:
             return URI(URIType.INVALID, uri, data=data)
         return URI(URIType.FILE, uri, data=data)
 
-    return URI(URIType.WEB, uri, data=uri)
+    if scheme == 'about':
+        # https://rfc-editor.org/rfc/rfc6694#section-2.1
+        data: dict[str, str] = {}
+        try:
+            token = unquote(urlparts.path, errors='strict')
+            if token == 'ambiguous-address':  # noqa: S105
+                data['addr'] = unquote(urlparts.query, errors='strict')
+                validate_jid(data['addr'], 'bare')
+                return URI(URIType.AT, uri, data=data)
+            raise Exception(f'Unrecognized about-token "{token}"')
+        except Exception as err:
+            data['error'] = str(err)
+            return URI(URIType.INVALID, uri, data=data)
+
+    return URI(URIType.OTHER, uri)
+
+
+def _handle_message_qtype(
+        jid: str, params: dict[str, str], account: str) -> None:
+    body = params.get('body')
+    # ^ For JOIN, this is a non-standard, but nice extension
+    app.window.start_chat_from_jid(account, jid, message=body)
+
+
+_xmpp_query_type_handlers = {
+    XmppUriQuery.NONE: _handle_message_qtype,
+    XmppUriQuery.MESSAGE: _handle_message_qtype,
+    XmppUriQuery.JOIN: _handle_message_qtype,
+}
 
 
 @catch_exceptions
@@ -1037,11 +1002,15 @@ def open_uri(uri: Union[URI, str], account: Optional[str] = None) -> None:
         else:
             log.info('Blocked opening a file URI, see %s option', opt_name)
 
-    elif uri.type in (URIType.MAIL, URIType.TEL):
+    elif uri.type in (URIType.MAIL, URIType.TEL, URIType.WEB, URIType.OTHER):
         open_uri_externally(uri.source)
 
-    elif uri.type in (URIType.WEB, URIType.GEO):
-        open_uri_externally(uri.data)
+    elif uri.type == URIType.GEO:
+        if Gio.AppInfo.get_default_for_uri_scheme('geo'):
+            open_uri_externally(uri.source)
+        else:
+            open_uri(
+                geo_provider_from_location(uri.data['lat'], uri.data['lon']))
 
     elif uri.type in (URIType.XMPP, URIType.AT):
         if account is None:
@@ -1051,7 +1020,7 @@ def open_uri(uri: Union[URI, str], account: Optional[str] = None) -> None:
         if uri.type == URIType.XMPP:
             jid = uri.data['jid']
         else:
-            jid = uri.data
+            jid = uri.data['addr']
 
         qtype, qparams = XmppUriQuery.from_str(uri.query_type), uri.query_params
         if not qtype:
@@ -1064,14 +1033,7 @@ def open_uri(uri: Union[URI, str], account: Optional[str] = None) -> None:
             # > <xmpp:example-node@example.com> rather than
             # > <xmpp:example-node@example.com?query>."
             qtype, qparams = XmppUriQuery.NONE, {}
-
-        if qtype == XmppUriQuery.JOIN:
-            app.app.activate_action(
-                'groupchat-join',
-                GLib.Variant('as', [account, jid]))
-        else:
-            message = qparams.get('body')
-            app.window.start_chat_from_jid(account, jid, message=message)
+        _xmpp_query_type_handlers[qtype](jid, qparams, account)
 
     elif uri.type == URIType.INVALID:
         log.warning('open_uri: Invalid %s', uri)
@@ -1112,6 +1074,16 @@ def open_file(path: Path) -> None:
     open_file_uri(path.as_uri())
 
 
+def open_directory(path: Path) -> None:
+    return open_file(path)
+
+
+def show_in_folder(path: Path) -> None:
+    if not DBusFileManager().show_items_sync([path.as_uri()]):
+        # Fall back to just opening the containing folder
+        open_directory(path.parent)
+
+
 def filesystem_path_from_uri(uri: str) -> Optional[Path]:
     puri = parse_uri(uri)
     if puri.type != URIType.FILE:
@@ -1450,37 +1422,31 @@ def warn_about_plain_connection(account: str,
                                 ) -> bool:
     warn = app.settings.get_account_setting(
         account, 'confirm_unencrypted_connection')
-    for type_ in connection_types:
-        if type_.is_plain and warn:
-            return True
-    return False
+    return any(type_.is_plain and warn for type_ in connection_types)
 
 
 def get_idle_status_message(state: str, status_message: str) -> str:
     message = app.settings.get(f'auto{state}_message')
     if not message:
-        message = status_message
-    else:
-        message = message.replace('$S', '%(status)s')
-        message = message.replace('$T', '%(time)s')
-        message = message % {
-            'status': status_message,
-            'time': app.settings.get(f'auto{state}time')
-        }
-    return message
+        return status_message
+
+    message = message.replace('$S', '%(status)s')
+    message = message.replace('$T', '%(time)s')
+    return message % {
+        'status': status_message,
+        'time': app.settings.get(f'auto{state}time')
+    }
 
 
 def get_group_chat_nick(account: str, room_jid: Union[JID, str]) -> str:
-    nick = app.nicks[account]
-
     client = app.get_client(account)
 
     bookmark = client.get_module('Bookmarks').get_bookmark(room_jid)
     if bookmark is not None:
         if bookmark.nick is not None:
-            nick = bookmark.nick
+            return bookmark.nick
 
-    return nick
+    return app.nicks[account]
 
 
 def get_random_muc_localpart() -> str:
@@ -1528,15 +1494,13 @@ def get_os_version() -> str:
 
 
 def get_gobject_version() -> str:
-    gobject_ver = '.'.join(map(str, GObject.pygobject_version))
-    return gobject_ver
+    return '.'.join(map(str, GObject.pygobject_version))
 
 
 def get_glib_version() -> str:
-    glib_ver = '.'.join(map(str, [GLib.MAJOR_VERSION,
-                                  GLib.MINOR_VERSION,
-                                  GLib.MICRO_VERSION]))
-    return glib_ver
+    return '.'.join(map(str, [GLib.MAJOR_VERSION,
+                              GLib.MINOR_VERSION,
+                              GLib.MICRO_VERSION]))
 
 
 def make_path_from_jid(base_path: Path, jid: JID) -> Path:
@@ -1550,24 +1514,3 @@ def make_path_from_jid(base_path: Path, jid: JID) -> Path:
     if jid.resource is not None:
         return path / jid.resource[:30]
     return path
-
-
-def make_http_request(uri: str,
-                      callback: Any,
-                      user_data: Optional[Any] = None) -> None:
-
-    proxy = determine_proxy()
-    if proxy is None:
-        resolver = None
-
-    else:
-        resolver = proxy.get_resolver()
-
-    session = Soup.Session()
-    session.props.proxy_resolver = resolver
-    session.props.user_agent = f'Gajim {app.version}'
-    message = Soup.Message.new('GET', uri)
-    if user_data is None:
-        session.queue_message(message, callback)
-    else:
-        session.queue_message(message, callback, user_data)
