@@ -29,26 +29,25 @@ from __future__ import annotations
 from typing import Any
 from typing import Optional
 
-import socket
 import logging
+import socket
 
 import nbxmpp
+from gi.repository import GLib
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import Iq
 from nbxmpp.structs import DiscoInfo
 from nbxmpp.structs import IqProperties
 from nbxmpp.structs import StanzaHandler
 
-from gi.repository import GLib
-
 from gajim.common import app
 from gajim.common import helpers
 from gajim.common import types
 from gajim.common.events import FileRequestError
 from gajim.common.file_props import FileProp
 from gajim.common.file_props import FilesProp
-from gajim.common.socks5 import Socks5SenderClient
 from gajim.common.modules.base import BaseModule
+from gajim.common.socks5 import Socks5SenderClient
 
 log = logging.getLogger('gajim.c.m.bytestream')
 
@@ -321,7 +320,7 @@ class Bytestream(BaseModule):
             my_ips = [my_ip]
             # all IPs from local DNS
             for addr in socket.getaddrinfo(socket.gethostname(), None):
-                if (not addr[4][0] in my_ips and
+                if (addr[4][0] not in my_ips and
                         not addr[4][0].startswith('127') and
                         not addr[4][0] == '::1'):
                     my_ips.append(addr[4][0])
@@ -360,7 +359,7 @@ class Bytestream(BaseModule):
         # check if we are connected with an IPv4 address
         try:
             socket.inet_aton(my_ip)
-        except socket.error:
+        except OSError:
             self._con.connection.send(iq)
             return
 
