@@ -15,6 +15,8 @@
 # You should have received a copy of the GNU General Public License
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
+
 from typing import Any
 from typing import cast
 from typing import Optional
@@ -23,17 +25,18 @@ import logging
 from enum import IntEnum
 from enum import unique
 
+import cairo
 from gi.repository import Gdk
 from gi.repository import GdkPixbuf
 from gi.repository import GLib
 from gi.repository import Gtk
-import cairo
 
 from gajim.common import app
 from gajim.common.const import AvatarSize
-from gajim.common.i18n import _
 from gajim.common.helpers import get_file_path_from_dnd_dropped_uri
+from gajim.common.i18n import _
 
+from . import types
 from .dialogs import ErrorDialog
 from .filechoosers import AvatarChooserDialog
 from .util import scale_with_ratio
@@ -125,11 +128,11 @@ class AvatarSelector(Gtk.Box):
         self._crop_area.show()
 
     def _on_load_clicked(self, _button: Gtk.Button) -> None:
-        def _on_file_selected(path: str) -> None:
-            self.prepare_crop_area(path)
+        def _on_file_selected(paths: list[str]) -> None:
+            self.prepare_crop_area(paths[0])
 
         AvatarChooserDialog(_on_file_selected,
-                            transient_for=self.get_toplevel(),
+                            transient_for=cast(Gtk.Window, self.get_toplevel()),
                             modal=True)
 
     def _on_drag_data_received(self,
@@ -214,7 +217,7 @@ class CropArea(Gtk.DrawingArea):
         self._color_shifted_pixbuf: Optional[GdkPixbuf.Pixbuf] = None
         self._current_cursor: Optional[Gdk.CursorType] = None
 
-        self._scale = float(0.0)
+        self._scale = 1.0
         self._image.x = 0
         self._image.y = 0
         self._image.width = 0
@@ -263,7 +266,7 @@ class CropArea(Gtk.DrawingArea):
         self._crop.x = int(abs((width - self._crop.width) / 2))
         self._crop.y = int(abs((height - self._crop.height) / 2))
 
-        self._scale = 0.0
+        self._scale = 1.0
         self._image.x = 0
         self._image.y = 0
         self._image.width = 0
@@ -286,7 +289,11 @@ class CropArea(Gtk.DrawingArea):
         return GdkPixbuf.Pixbuf.new_subpixbuf(
             self._browse_pixbuf, self._crop.x, self._crop.y, width, height)
 
-    def _on_draw(self, _widget: Gtk.Widget, context: cairo.Context) -> bool:
+    def _on_draw(self,
+                 _widget: Gtk.Widget,
+                 context: cairo.Context[types.SomeSurface]
+                 ) -> bool:
+
         if self._browse_pixbuf is None:
             return False
 
@@ -655,7 +662,7 @@ class CropArea(Gtk.DrawingArea):
 
             self._generate_color_shifted_pixbuf()
 
-            if self._scale == 0.0:
+            if self._scale == 1.0:
                 scale_to_80 = float(min(
                     (self._pixbuf.get_width() * 0.8 / self._base_width),
                     (self._pixbuf.get_height() * 0.8 / self._base_height)))
