@@ -15,44 +15,41 @@
 from __future__ import annotations
 
 from typing import Any
+from typing import cast
 from typing import Optional
 from typing import Union
-from typing import cast
 
 import logging
 import time
 
 from gi.repository import Gio
-from gi.repository import Gtk
 from gi.repository import GLib
-
+from gi.repository import Gtk
 from nbxmpp import JID
 from nbxmpp.const import StatusCode
-from nbxmpp.structs import MucSubject
 from nbxmpp.modules.security_labels import Displaymarking
+from nbxmpp.structs import MucSubject
 
 from gajim.common import app
 from gajim.common import events
 from gajim.common import ged
 from gajim.common import helpers
 from gajim.common import types
-from gajim.common.helpers import get_file_path_from_dnd_dropped_uri
-from gajim.common.helpers import to_user_string
-from gajim.common.i18n import _
+from gajim.common.const import KindConstant
 from gajim.common.ged import EventHelper
 from gajim.common.helpers import AdditionalDataDict
 from gajim.common.helpers import get_retraction_text
-from gajim.common.const import KindConstant
+from gajim.common.helpers import to_user_string
+from gajim.common.i18n import _
 from gajim.common.modules.contacts import BareContact
-from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.modules.contacts import GroupchatContact
+from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.modules.httpupload import HTTPFileTransfer
 from gajim.common.storage.archive import ConversationRow
-
+from gajim.gui.builder import get_builder
+from gajim.gui.conversation.jump_to_end_button import JumpToEndButton
 from gajim.gui.conversation.message_selection import MessageSelection
 from gajim.gui.conversation.view import ConversationView
-from gajim.gui.conversation.jump_to_end_button import JumpToEndButton
-from gajim.gui.builder import get_builder
 from gajim.gui.groupchat_roster import GroupchatRoster
 from gajim.gui.groupchat_state import GroupchatState
 
@@ -496,18 +493,8 @@ class ChatControl(EventHelper):
         self.reset_view()
 
     def drag_data_file_transfer(self, selection: Gtk.SelectionData) -> None:
-        uris = selection.get_uris()
-        paths: list[str] = []
-        for uri in uris:
-            path = get_file_path_from_dnd_dropped_uri(uri)
-            if path is None or not path.is_file():
-                self.add_info_message(
-                    _('You dropped something Gajim could not '
-                      'process: %s' % path))
-                continue
-            paths.append(str(path))
-
-        app.window.activate_action('send-file', GLib.Variant('as', paths))
+        app.window.activate_action('send-file',
+                                   GLib.Variant('as', selection.get_uris()))
 
     def get_our_nick(self) -> str:
         if isinstance(self.contact, GroupchatParticipant):
