@@ -17,18 +17,15 @@ from __future__ import annotations
 from typing import Optional
 from typing import Union
 
+import textwrap
 from datetime import datetime
 from datetime import timedelta
-import textwrap
 
-from gi.repository import Gdk
+import cairo
 from gi.repository import GdkPixbuf
 from gi.repository import GLib
 from gi.repository import Gtk
 from gi.repository import Pango
-
-import cairo
-
 from nbxmpp.errors import StanzaError
 from nbxmpp.modules.security_labels import Displaymarking
 from nbxmpp.structs import CommonError
@@ -38,27 +35,26 @@ from gajim.common.const import AvatarSize
 from gajim.common.const import Trust
 from gajim.common.const import TRUST_SYMBOL_DATA
 from gajim.common.helpers import AdditionalDataDict
-from gajim.common.helpers import from_one_line
 from gajim.common.helpers import get_group_chat_nick
 from gajim.common.helpers import message_needs_highlight
 from gajim.common.helpers import to_user_string
 from gajim.common.i18n import _
 from gajim.common.i18n import is_rtl_text
 from gajim.common.modules.contacts import GroupchatContact
+from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.types import ChatContactT
+from gajim.gtk.menus import get_chat_row_menu
 
+from ...preview import PreviewWidget
+from ...util import format_fingerprint
+from ...util import GajimPopover
+from ..message_widget import MessageWidget
 from .base import BaseRow
 from .widgets import AvatarBox
 from .widgets import DateTimeLabel
-from .widgets import NicknameLabel
 from .widgets import MessageIcons
 from .widgets import MoreMenuButton
-from ..message_widget import MessageWidget
-from ...dialogs import InputDialog
-from ...dialogs import DialogButton
-from ...preview import PreviewWidget
-from ...util import format_fingerprint
-
+from .widgets import NicknameLabel
 
 MERGE_TIMEFRAME = timedelta(seconds=120)
 
@@ -121,7 +117,8 @@ class MessageRow(BaseRow):
 
         if is_previewable:
             muc_context = None
-            if isinstance(self._contact, GroupchatContact):
+            if isinstance(self._contact,
+                          (GroupchatContact, GroupchatParticipant)):
                 muc_context = self._contact.muc_context
             self._message_widget = PreviewWidget(account)
             app.preview_manager.create_preview(
@@ -191,7 +188,7 @@ class MessageRow(BaseRow):
             self._bottom_box.set_halign(Gtk.Align.END)
             self._message_widget.set_direction(Gtk.TextDirection.RTL)
 
-        more_menu_button = MoreMenuButton(self, self._contact, name)
+        more_menu_button = MoreMenuButton(self._on_more_menu_button_clicked)
         self._bottom_box.pack_end(more_menu_button, False, True, 0)
 
         self.grid.attach(self._avatar_box, 0, 0, 1, 2)
@@ -200,6 +197,19 @@ class MessageRow(BaseRow):
 
         self.show_all()
 
+    def _on_more_menu_button_clicked(self, button: Gtk.Button) -> None:
+        menu = get_chat_row_menu(
+            self._contact,
+            self.name,
+            self.get_text(),
+            self.timestamp,
+            self.message_id,
+            self.stanza_id,
+            self.log_line_id)
+
+        popover = GajimPopover(menu, relative_to=button)
+        popover.popup()
+
     def enable_selection_mode(self) -> None:
         if isinstance(self._message_widget, MessageWidget):
             self._message_widget.set_selectable(False)
@@ -312,37 +322,6 @@ class MessageRow(BaseRow):
     def get_text(self) -> str:
         return self._message_widget.get_text()
 
-    def on_copy_message(self, _widget: Gtk.Widget) -> None:
-        time_format = from_one_line(app.settings.get('chat_timestamp_format'))
-        timestamp_formatted = self.timestamp.strftime(time_format)
-
-        clip = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-        text = self.get_text()
-        clip.set_text(f'{timestamp_formatted} - {self.name}: {text}', -1)
-
-    def on_quote_message(self, _widget: Gtk.Widget) -> None:
-        app.window.activate_action(
-            'quote', GLib.Variant('s', self.get_text()))
-
-    def on_correct_message(self, _widget: Gtk.Widget) -> None:
-        app.window.activate_action('correct-message', None)
-
-    def on_retract_message(self, _widget: Gtk.Widget) -> None:
-        def _on_retract(reason: str) -> None:
-            self._client.get_module('MUC').retract_message(
-                self._contact.jid, self.stanza_id, reason or None)
-
-        InputDialog(
-            _('Retract Message'),
-            _('Retract message?'),
-            _('Why do you want to retract this message?'),
-            [DialogButton.make('Cancel'),
-             DialogButton.make('Remove',
-                               text=_('_Retract'),
-                               callback=_on_retract)],
-            input_str=_('Spam'),
-            transient_for=app.window).show()
-
     def _get_encryption_image(self,
                               additional_data: AdditionalDataDict,
                               ) -> Optional[Gtk.Image]:
