@@ -20,13 +20,12 @@ from typing import cast
 from typing import Optional
 from typing import Union
 
-from gi.repository import Gtk
 from gi.repository import GLib
 from gi.repository import GObject
+from gi.repository import Gtk
 from gi.repository import Pango
-
-from nbxmpp.modules.dataforms import extend_form
 from nbxmpp.modules.dataforms import DataField
+from nbxmpp.modules.dataforms import extend_form
 from nbxmpp.modules.dataforms import MultipleDataForm
 from nbxmpp.modules.dataforms import SimpleDataForm
 from nbxmpp.modules.dataforms import Uri
@@ -34,15 +33,14 @@ from nbxmpp.protocol import InvalidJid
 from nbxmpp.simplexml import Node
 
 from gajim.common import app
-from gajim.common.i18n import _
 from gajim.common.helpers import open_uri
+from gajim.common.i18n import _
 
-from .util import MultiLineLabel
-from .util import MaxWidthComboBoxText
 from .util import make_href_markup
+from .util import MaxWidthComboBoxText
+from .util import MultiLineLabel
 from .util import scale_pixbuf_from_data
 
-
 # Options
 
 #  no-scrolling                 No scrollbars
@@ -187,7 +185,7 @@ class FormGrid(Gtk.Grid):
             # Don’t overwrite option
             return
 
-        label_lengths = set([0])
+        label_lengths = {0}
         for field in form_node.iter_fields():
             if field.type_ == 'hidden':
                 continue
@@ -516,9 +514,7 @@ class ListMutliTreeView(Gtk.TreeView):
             self._store.append(
                 [label, value, label, value in field.values])
 
-        labels_over_max_width = map(lambda x: len(x) > 40,
-                                    [option[0] for option in field.options])
-        if any(labels_over_max_width):
+        if any(filter(lambda x: len(x[0]) > 40, field.options)):
             self.set_tooltip_column(2)
 
         self.set_model(self._store)
