@@ -17,26 +17,25 @@ from __future__ import annotations
 from typing import Any
 from typing import Optional
 
-import os
-import tempfile
 import logging
+import tempfile
 import uuid
+from pathlib import Path
 
-from gi.repository import GLib
 from gi.repository import Gdk
 from gi.repository import Gio
-from gi.repository import Gtk
+from gi.repository import GLib
 from gi.repository import GObject
-
+from gi.repository import Gtk
 from nbxmpp.const import Chatstate
 from nbxmpp.modules.security_labels import SecurityLabel
 
 from gajim.common import app
-from gajim.common.commands import CommandFailed
-from gajim.common.i18n import _
 from gajim.common.client import Client
-from gajim.common.const import SimpleClientState
+from gajim.common.commands import CommandFailed
 from gajim.common.const import Direction
+from gajim.common.const import SimpleClientState
+from gajim.common.i18n import _
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
 from gajim.common.types import ChatContactT
@@ -154,6 +153,7 @@ class MessageActionsBox(Gtk.Grid):
 
         elif action_name == 'show-emoji-chooser':
             self.msg_textview.emit('insert-emoji')
+            self._ui.emoticons_button.set_active(False)
 
         elif action_name == 'quote':
             assert param
@@ -507,15 +507,14 @@ class MessageActionsBox(Gtk.Grid):
             assert self._contact is not None
 
             message = self.msg_textview.get_text()
-            if (message.startswith('/') and
-                    not message.startswith('//') and
-                    not message.startswith('/me ')):
-                try:
-                    app.commands.parse(self._contact.type_string, message)
-                except CommandFailed:
-                    pass
-                else:
-                    self.msg_textview.clear()
+
+            try:
+                handled = app.commands.parse(self._contact.type_string, message)
+            except CommandFailed:
+                return True
+
+            if handled:
+                self.msg_textview.clear()
                 return True
 
             if not app.account_is_available(self._contact.account):
@@ -531,22 +530,30 @@ class MessageActionsBox(Gtk.Grid):
         return False
 
     def _on_paste_clipboard(self,
-                            _texview: MessageInputTextView
+                            texview: MessageInputTextView
                             ) -> None:
 
         clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
+
+        uris = clipboard.wait_for_uris()
+        if uris:
+            app.window.activate_action('send-file', GLib.Variant('as', uris))
+            # prevent TextView from pasting the URIs as text:
+            texview.stop_emission_by_name('paste-clipboard')
+            return
+        log.info('No URIs pasted')
+
         image = clipboard.wait_for_image()
         if image is None:
             log.info('No image pasted')
             return
 
-        temp_dir = tempfile.gettempdir()
-        image_path = os.path.join(temp_dir, f'{uuid.uuid4()}.png')
+        temp_dir = Path(tempfile.gettempdir())
+        image_path = temp_dir / f'{uuid.uuid4()}.png'
 
-        image.savev(image_path, 'png', [], [])
-        if image is None:
+        if not image.savev(str(image_path), 'png', [], []):
             log.error('Could not process pasted image')
             return
 
         app.window.activate_action(
-            'send-file', GLib.Variant('as', [image_path]))
+            'send-file', GLib.Variant('as', [image_path.as_uri()]))
