@@ -23,31 +23,28 @@ from enum import IntEnum
 from enum import unique
 from pathlib import Path
 
-from gi.repository import Gtk
-from gi.repository import GdkPixbuf
 from gi.repository import Gdk
+from gi.repository import GdkPixbuf
+from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common import ged
-from gajim.common.i18n import _
-from gajim.common.events import PluginAdded
-from gajim.common.events import PluginRemoved
 from gajim.common.exceptions import PluginsystemError
 from gajim.common.helpers import open_uri
+from gajim.common.i18n import _
 from gajim.common.types import PluginRepositoryT
-
-from gajim.plugins.helpers import GajimPluginActivateException
-from gajim.plugins.pluginmanager import PluginManifest
-
-from gajim.gui.dialogs import WarningDialog
-from gajim.gui.dialogs import DialogButton
-from gajim.gui.dialogs import ConfirmationDialog
-from gajim.gui.filechoosers import ArchiveChooserDialog
 from gajim.gui.builder import get_builder
-from gajim.gui.util import load_icon_pixbuf
+from gajim.gui.dialogs import ConfirmationDialog
+from gajim.gui.dialogs import DialogButton
+from gajim.gui.dialogs import WarningDialog
+from gajim.gui.filechoosers import ArchiveChooserDialog
 from gajim.gui.util import EventHelper
-
+from gajim.gui.util import load_icon_pixbuf
+from gajim.plugins.events import PluginAdded
+from gajim.plugins.events import PluginRemoved
+from gajim.plugins.helpers import GajimPluginActivateException
+from gajim.plugins.manifest import PluginManifest
 
 log = logging.getLogger('gajim.gui.plugins')
 
@@ -333,8 +330,7 @@ class PluginsWindow(Gtk.ApplicationWindow, EventHelper):
             try:
                 app.plugin_manager.activate_plugin(plugin)
             except GajimPluginActivateException as e:
-                WarningDialog(_('Plugin failed'), str(e),
-                              transient_for=self)
+                WarningDialog(_('Plugin failed'), str(e))
                 return
 
         self._update_selected_plugin()
@@ -361,7 +357,7 @@ class PluginsWindow(Gtk.ApplicationWindow, EventHelper):
             app.plugin_manager.uninstall_plugin(plugin)
         except PluginsystemError as error:
             WarningDialog(_('Unable to properly remove the plugin'),
-                          str(error), self)
+                          str(error))
             return
 
     def _on_plugin_removed(self, event: PluginRemoved) -> None:
@@ -398,9 +394,7 @@ class PluginsWindow(Gtk.ApplicationWindow, EventHelper):
     def _on_install_plugin_from_zip(self, _button: Gtk.ToolButton) -> None:
         def _show_warn_dialog() -> None:
             text = _('Archive is malformed')
-            dialog = WarningDialog(text, '', transient_for=self)
-            dialog.set_modal(False)
-            dialog.popup()
+            WarningDialog(text, transient_for=self)
 
         def _on_plugin_exists(zip_filename: str) -> None:
             def _on_yes():
@@ -420,7 +414,8 @@ class PluginsWindow(Gtk.ApplicationWindow, EventHelper):
                                    callback=_on_yes)],
                 transient_for=self).show()
 
-        def _try_install(zip_filename: str) -> None:
+        def _try_install(paths: list[str]) -> None:
+            zip_filename = paths[0]
             try:
                 plugin = app.plugin_manager.install_from_zip(zip_filename)
             except PluginsystemError as er_type:
@@ -429,7 +424,7 @@ class PluginsWindow(Gtk.ApplicationWindow, EventHelper):
                     _on_plugin_exists(zip_filename)
                     return
 
-                WarningDialog(error_text, f'"{zip_filename}"', self)
+                WarningDialog(error_text, f'"{zip_filename}"')
                 return
             if not plugin:
                 _show_warn_dialog()
