@@ -13,43 +13,43 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 from __future__ import annotations
+
 from typing import Any
-from typing import Optional
 from typing import cast
-from typing import Type
+from typing import Optional
 
 import logging
 import sys
 
-from gi.repository import Gtk
 from gi.repository import Gdk
+from gi.repository import Gtk
 
 from gajim.common import app
 from gajim.common import configpaths
 from gajim.common.const import THRESHOLD_OPTIONS
+from gajim.common.events import StyleChanged
+from gajim.common.events import ThemeUpdate
+from gajim.common.helpers import open_directory
 from gajim.common.i18n import _
-from gajim.common.helpers import open_file
 from gajim.common.multimedia_helpers import AudioInputManager
 from gajim.common.multimedia_helpers import AudioOutputManager
 from gajim.common.multimedia_helpers import VideoInputManager
-from gajim.common.events import StyleChanged
-from gajim.common.events import ThemeUpdate
 from gajim.common.setting_values import BoolSettings
 
+from .builder import get_builder
 from .const import Setting
 from .const import SettingKind
 from .const import SettingType
-from .dialogs import DialogButton
 from .dialogs import ConfirmationDialog
+from .dialogs import DialogButton
+from .preview import PREVIEW_ACTIONS
 from .settings import PopoverSetting
 from .settings import SettingsBox
 from .settings import SettingsDialog
 from .sidebar_switcher import SideBarSwitcher
-from .video_preview import VideoPreview
-from .preview import PREVIEW_ACTIONS
-from .util import open_window
 from .util import get_app_window
-from .builder import get_builder
+from .util import open_window
+from .video_preview import VideoPreview
 
 # if app.is_installed('GSPELL'):
 #     from gi.repository import Gspell  # pylint: disable=ungrouped-imports
@@ -79,7 +79,7 @@ class Preferences(Gtk.ApplicationWindow):
 
         self.add(self._ui.grid)
 
-        prefs: list[tuple[str, Type[PreferenceBox]]] = [
+        prefs: list[tuple[str, type[PreferenceBox]]] = [
             ('window_behaviour', WindowBehaviour),
             ('plugins', Plugins),
             ('general', General),
@@ -116,10 +116,10 @@ class Preferences(Gtk.ApplicationWindow):
     def get_ui(self):
         return self._ui
 
-    def _add_prefs(self, prefs: list[tuple[str, Type[PreferenceBox]]]):
+    def _add_prefs(self, prefs: list[tuple[str, type[PreferenceBox]]]):
         for ui_name, klass in prefs:
             pref_box = getattr(self._ui, ui_name)
-            pref = klass(self)
+            pref = klass(self)  # pyright: ignore
             pref_box.add(pref)
             self._prefs[ui_name] = pref
 
@@ -916,10 +916,7 @@ class Miscellaneous(PreferenceBox):
         popover_row.update_entries(self._get_proxies())
 
     def _check_hints_reset(self) -> bool:
-        for hint in self._hints_list:
-            if app.settings.get(hint) is False:
-                return True
-        return False
+        return any(app.settings.get(hint) is False for hint in self._hints_list)
 
     def _on_reset_hints(self, button: Gtk.Button) -> None:
         for hint in self._hints_list:
@@ -978,7 +975,7 @@ class Advanced(PreferenceBox):
 
     @staticmethod
     def _on_open_debug_logs(*args: Any) -> None:
-        open_file(configpaths.get('DEBUG'))
+        open_directory(configpaths.get('DEBUG'))
 
     @staticmethod
     def _on_advanced_config_editor(*args: Any) -> None:
