@@ -2,25 +2,25 @@ import unittest
 from unittest.mock import MagicMock
 
 from gajim import gui
+
 gui.init('gtk')
 
 from gajim.common import app  # Avoids circular imports from common.helpers
-import gajim.common.styling as styling
+from gajim.common import styling
+from gajim.common.styling import EmphasisSpan
+from gajim.common.styling import Hyperlink
 from gajim.common.styling import PlainBlock
 from gajim.common.styling import PreBlock
-from gajim.common.styling import QuoteBlock
 from gajim.common.styling import PreTextSpan
-from gajim.common.styling import StrongSpan
-from gajim.common.styling import EmphasisSpan
-from gajim.common.styling import StrikeSpan
-from gajim.common.styling import Hyperlink
 from gajim.common.styling import process_uris
-from gajim.common.text_helpers import jid_to_iri
-
+from gajim.common.styling import QuoteBlock
+from gajim.common.styling import StrikeSpan
+from gajim.common.styling import StrongSpan
+from gajim.common.util.text import escape_iri_query
 
 app.settings = MagicMock()
-app.settings.get.return_value = 'a a- a. scheme'  # additional_uri_schemes
-
+# additional_uri_schemes
+app.settings.get = MagicMock(return_value='a a- a. scheme')
 
 STYLING = {
     'pre cannot have children':  {
@@ -313,6 +313,7 @@ URIS = [
     'file:///x:/foo/bar/baz',  # windows
     'file://localhost/foo/bar/baz',
     'file://nonlocalhost/foo/bar/baz',
+    'about:ambiguous-address?a@b.c',
 
     # These seem to be from https://mathiasbynens.be/demo/url-regex
     'http://foo.com/blah_blah',
@@ -347,7 +348,7 @@ URIS = [
     'http://مثال.إختبار',
     'http://例子.测试',
     'http://उदाहरण.परीक्षा',
-    'http://-.~_!$&\'()*+,;=:%40:80%2f::::::@example.com',
+    "http://-.~_!$&'()*+,;=:%40:80%2f::::::@example.com",
     'http://1337.net',
     'http://a.b-c.de',
     'http://223.255.255.254',
@@ -424,7 +425,7 @@ UNACCEPTABLE_URIS = [
 
     'geo:1,',
     'geo:,2',
-    #'geo:1,2,',  FIXME: wrongly parsed as valid
+    # 'geo:1,2,',  FIXME: wrongly parsed as valid
     'geo:1,,3',
     'geo:,2,3',
     'geo:1,,',
@@ -437,6 +438,11 @@ UNACCEPTABLE_URIS = [
     'file:a/',
     'file:a/b',
 
+    'about:',
+    'about:asdfasdf',
+    'about:ambiguous-address',
+    'about:ambiguous-address?',
+
     'mailtomailto:foo@bar.com.uk',
 ]
 
@@ -480,13 +486,13 @@ JIDS = [
     r'somenick!user\22\26\27\2f\3a\3c\3e\5c3address@example.com',
 
     # https://en.wikipedia.org/wiki/E-mail_address#Internationalization_examples
-    # Do note that these are *e-mail* addresses and might not all be vaild JIDs.
+    # Do note that these are *e-mail* addresses and might not all be valid JIDs.
     'Pelé@example.com',
     'δοκιμή@παράδειγμα.δοκιμή',
     '我買@屋企.香港',
     '二ノ宮@黒川.日本',
     'медведь@с-балалайкой.рф',
-    #'संपर्क@डाटामेल.भारत',  fails because of the 2 combining chars in localpart
+    # 'संपर्क@डाटामेल.भारत',  fails because of the 2 combining chars in localpart
 ]
 
 NONJIDS = [
@@ -530,33 +536,33 @@ class Test(unittest.TestCase):
         for uri in URIS:
             text = self.wrap(uri)
             hlinks = process_uris(text)
-            self.assertEqual([l.uri for l in hlinks], [uri], text)
+            self.assertEqual([link.uri for link in hlinks], [uri], text)
 
     def test_invalid_uris(self):
         for foo in NONURIS + UNACCEPTABLE_URIS:
             text = self.wrap(foo)
             hlinks = process_uris(text)
-            self.assertEqual([l.text for l in hlinks], [], text)
+            self.assertEqual([link.text for link in hlinks], [], text)
 
     def test_jids(self):
-        for jid in JIDS:
-            text = self.wrap(jid)
-            uri = jid_to_iri(jid)
+        for jidlike in JIDS:
+            text = self.wrap(jidlike)
+            uri = 'about:ambiguous-address?' + escape_iri_query(jidlike)
             hlinks = process_uris(text)
-            self.assertEqual([(l.text, l.uri) for l in hlinks],
-                             [(jid, uri)], text)
+            self.assertEqual([(link.text, link.uri) for link in hlinks],
+                             [(jidlike, uri)], text)
 
     def test_nonjids(self):
         for foo in NONJIDS:
             text = self.wrap(foo)
             hlinks = process_uris(text)
-            self.assertEqual([l.text for l in hlinks], [], text)
+            self.assertEqual([link.text for link in hlinks], [], text)
 
     def test_uris_with_text(self):
         for text, results in URIS_WITH_TEXT:
             hlinks = process_uris(text)
-            self.assertEqual([l.text for l in hlinks], results, text)
+            self.assertEqual([link.text for link in hlinks], results, text)
 
 
-if __name__ == "__main__":
+if __name__ == '__main__':
     unittest.main()
